==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/gui/actions/file/SaveFileAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.file;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.helper.SyncThread;
import org.herac.tuxguitar.gui.util.FileChooser;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SaveFileAction extends Action{
    public static final String NAME = "SAVE_FILE";
    
    public SaveFileAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        String defaultChooserPath =  getEditor().getMemoryHelper().getLastChooserPath();
        String defaultFileName =  getDefaultFileName(getEditor().getMemoryHelper().getFileName());
        
        String[] filterNames = null;//new String[] { "Suported Files (*.tg,*.gp3)" };
        String[] filterExtensions = new String[] { "*.gp4","*.gp3","*.tg" };
        FileChooser chooser = new FileChooser(getEditor(), filterNames, filterExtensions,defaultChooserPath,defaultFileName);
        String selectedName = chooser.show(SWT.SAVE);
        if (selectedName != null) {
            getEditor().getTablature().changeCursor(SWT.CURSOR_WAIT);
            
            if(!isSuportedFormat(selectedName)){
                selectedName += getDefaultExtension();
            }
            final String fileName = selectedName;
            
            new Thread(new Runnable() {
                public void run() {
                    getEditor().getSongManager().save(fileName);
                    getEditor().notifyMemoryHelper(fileName);
                    
                    new SyncThread(getEditor(), new Runnable() {
                        public void run() {
                            getEditor().getTablature().changeCursor(SWT.CURSOR_ARROW);
                        }
                    }).start();                                                             
                }
            }).start();
        }   
        
        return true;
    }


    private String getDefaultFileName(String fileName){
        String defaultFileName = "untitled";
        String defaultExtencion = getDefaultExtension();
        if(fileName == null){
            fileName = defaultFileName + defaultExtencion;
        }else if(!isSuportedFormat(fileName)){
            fileName = chengeFormat(fileName,defaultExtencion);
        }
        
        
        return fileName;
    }
    
    private boolean isSuportedFormat(String fileName){
        return (fileName.endsWith(".tg") || fileName.endsWith(".gp3") || fileName.endsWith(".gp4"));
    }
    
    
    private String chengeFormat(String fileName,String format){
        return removeExtension(fileName) + format;
    }    
    
    private String removeExtension(String fileName){
        int index = fileName.lastIndexOf('.');
        return fileName.substring(0,index);   
    }
    
    private String getDefaultExtension(){
        return  ".gp4";
    }
   
}

==> TuxGuitar-0.4.tar.gz: TuxGuitar-0.4/src/org/herac/tuxguitar/gui/actions/file/SaveFileAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.file;

import java.io.File;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.helper.SyncThread;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SaveFileAction extends Action{
    public static final String NAME = "SAVE_FILE";
    
    public SaveFileAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
    	String path =  getEditor().getMemoryHelper().getLastChooserPath();
        String name = getEditor().getMemoryHelper().getFileName();

        if (path == null || name == null) {
        	TuxGuitar.instance().getAction(SaveAsFileAction.NAME).doAction(e);
        }else{
            getEditor().getTablature().changeCursor(SWT.CURSOR_WAIT);

            final String fileName = path + File.separator + name ;
            
            new Thread(new Runnable() {
                public void run() {
                    getEditor().getSongManager().save(fileName);
                    getEditor().notifyMemoryHelper(fileName);
                    
                    new SyncThread(getEditor(), new Runnable() {
                        public void run() {
                            getEditor().getTablature().changeCursor(SWT.CURSOR_ARROW);
                        }
                    }).start();                                                             
                }
            }).start();
        }   
        
        return true;
    }

}
